<!doctype html>
<html lang="en-us" class="layout-pf">
  <head>
    <meta charset="utf-8">
    <title>Cockpit-Composer</title>
    <link rel="stylesheet" href="./css/patternfly.min.css">
    <link rel="stylesheet" href="./css/patternfly-additions.min.css">
    <link rel="stylesheet" href="./custom.css">

    <!-- js dependencies -->
    <script type="text/javascript" src="../base1/cockpit.js"></script>
    <script type="text/javascript" src="../*/po.js"></script>
    <script src="./config.js"></script>
  </head>
  <body>
    <div id="main"></div>
  </body>
</html>
